@@ -82,12 +82,12 @@ class CLIParser:
             metavar="<url>",
         )
         parser.add_argument(
-            "--mustache",
-            "-m",
+            "--variable",
+            "-V",
             type=str,
             required=False,
             action="append",
-            help="user-defined Mustache substitution; can be supplied multiple times",
+            help="user-defined Mustache variable substitution; can be supplied multiple times",
             metavar="<var1=v1>",
         )
         parser.add_argument(
@@ -204,6 +204,13 @@ class CLIParser:
                 required=False,
                 help="abort all running tasks with immediate effect",
             )
+            parser.add_argument(
+                "--follow",
+                "-f",
+                action="store_true",
+                required=False,
+                help="when using --abort, poll until all Tasks have been aborted",
+            )
 
         if any(
             module in sys.argv[0]
@@ -410,8 +417,8 @@ class CLIParser:
         return self.args.url
 
     @property
-    def mustache_subs(self) -> Optional[List[str]]:
-        return self.args.mustache
+    def variables(self) -> Optional[List[str]]:
+        return self.args.variable
 
     @property
     def quiet(self) -> bool:
@@ -569,6 +576,8 @@ def lookup_module_description(module_name: str) -> Optional[str]:
         suffix = "listing entities"
     elif "instantiate" in module_name:
         suffix = "provisioning a Compute Requirement"
+    elif "upload" in module_name:
+        suffix = "uploading objects to the Object Store"
 
     return None if suffix is None else prefix + suffix
 
