@@ -36,7 +36,7 @@ MAX_RETRIES = "maximumTaskRetries"  # Integer
 MAX_WORKERS = "maxWorkers"  # Integer
 MIN_NODES = "minNodes"  # Integer
 MIN_WORKERS = "minWorkers"  # Integer
-MUSTACHE = "mustache"  # Dictionary
+VARIABLES = "variables"  # Dictionary
 NAME = "name"  # String
 NAMESPACE = "namespace"  # String
 NAME_TAG = "tag"  # String
@@ -120,7 +120,7 @@ ALL_KEYS = [
     MAX_WORKERS,
     MIN_NODES,
     MIN_WORKERS,
-    MUSTACHE,
+    VARIABLES,
     NAMESPACE,
     NAME_TAG,
     NODE_BOOT_TIME_LIMIT,
